from __future__ import (absolute_import, division, print_function,
                        unicode_literals)

import datetime  # For datetime objects
import os.path  # To manage paths
import sys  # To find out the script name (in argv[0])

# Import the backtrader platform
import backtrader as bt
import yfinance as yf


# Create a Stratey
class TestStrategy(bt.Strategy):
    params = (
        ('maperiod', 15),
    )

    def log(self, txt, dt=None):
        ''' Logging function fot this strategy'''
        dt = dt or self.datas[0].datetime.date(0)
        print('%s, %s' % (dt.isoformat(), txt))

    def __init__(self):
        # Keep a reference to the "close" line in the data[0] dataseries
        self.dataclose = self.datas[0].close

        # To keep track of pending orders and buy price/commission
        self.order = None
        self.buyprice = None
        self.buycomm = None

        # Add a MovingAverageSimple indicator
        self.sma = bt.indicators.SimpleMovingAverage(
            self.datas[0], period=self.params.maperiod)

        # Indicators for the plotting show
        bt.indicators.ExponentialMovingAverage(self.datas[0], period=25)
        bt.indicators.WeightedMovingAverage(self.datas[0], period=25,
                                            subplot=True)
        bt.indicators.StochasticSlow(self.datas[0])
        bt.indicators.MACDHisto(self.datas[0])
        rsi = bt.indicators.RSI(self.datas[0])
        bt.indicators.SmoothedMovingAverage(rsi, period=10)
        bt.indicators.ATR(self.datas[0], plot=False)

    def notify_order(self, order):
        if order.status in [order.Submitted, order.Accepted]:
            # Buy/Sell order submitted/accepted to/by broker - Nothing to do
            return

        # Check if an order has been completed
        # Attention: broker could reject order if not enough cash
        if order.status in [order.Completed]:
            if order.isbuy():
                self.log(
                    'BUY EXECUTED, Price: %.2f, Cost: %.2f, Comm %.2f' %
                    (order.executed.price,
                     order.executed.value,
                     order.executed.comm))

                self.buyprice = order.executed.price
                self.buycomm = order.executed.comm
            else:  # Sell
                self.log('SELL EXECUTED, Price: %.2f, Cost: %.2f, Comm %.2f' %
                         (order.executed.price,
                          order.executed.value,
                          order.executed.comm))

            self.bar_executed = len(self)

        elif order.status in [order.Canceled, order.Margin, order.Rejected]:
            self.log('Order Canceled/Margin/Rejected')

        # Write down: no pending order
        self.order = None

    def notify_trade(self, trade):
        if not trade.isclosed:
            return

        self.log('OPERATION PROFIT, GROSS %.2f, NET %.2f' %
                 (trade.pnl, trade.pnlcomm))

    def next(self):
        # Simply log the closing price of the series from the reference
        self.log('Close, %.2f' % self.dataclose[0])

        # Check if an order is pending ... if yes, we cannot send a 2nd one
        if self.order:
            return

        # Check if we are in the market
        if not self.position:

            # Not yet ... we MIGHT BUY if ...
            if self.dataclose[0] > self.sma[0]:

                # BUY, BUY, BUY!!! (with all possible default parameters)
                self.log('BUY CREATE, %.2f' % self.dataclose[0])

                # Keep track of the created order to avoid a 2nd order
                self.order = self.buy()

        else:

            if self.dataclose[0] < self.sma[0]:
                # SELL, SELL, SELL!!! (with all possible default parameters)
                self.log('SELL CREATE, %.2f' % self.dataclose[0])

                # Keep track of the created order to avoid a 2nd order
                self.order = self.sell()


if __name__ == '__main__':
    # Create a cerebro entity
    cerebro = bt.Cerebro()

    # Add a strategy
    cerebro.addstrategy(TestStrategy)

    # Datas are in a subfolder of the samples. Need to find where the script is
    # because it could have been called from anywhere
    modpath = os.path.dirname(os.path.abspath(sys.argv[0]))
    datapath = os.path.join(modpath, '../datas/orcl-1995-2014.txt')

    # Create a Data Feed
    data = bt.feeds.YahooFinanceCSVData(
    dataname=datapath,  
    # Do not pass values before this date
    fromdate=datetime.datetime(2000, 1, 1),
    # Do not pass values before this date
    todate=datetime.datetime(2000, 12, 31),
    # Do not pass values after this date
    reverse=False)
    
    #data = bt.feeds.PandasData(dataname=yf.download('AAPL', '2000-07-06', '2020-07-07', auto_adjust=True))

    #data = bt.feeds.PandasData(dataname=yf.download('AAPL', '2018-07-01', '2021-07-30', auto_adjust=False))
    
    # Add the Data Feed to Cerebro
    cerebro.adddata(data)

    # Set our desired cash start
    cerebro.broker.setcash(1000.0)

    # Add a FixedSize sizer according to the stake
    cerebro.addsizer(bt.sizers.FixedSize, stake=10)

    # Set the commission
    cerebro.broker.setcommission(commission=0.0)

    # Print out the starting conditions
    print('Starting Portfolio Value: %.2f' % cerebro.broker.getvalue())

    # Run over everything
    cerebro.run()

    # Print out the final result
    print('Final Portfolio Value: %.2f' % cerebro.broker.getvalue())

    # Plot the result
    cerebro.plot()



# BLMainStrategy
# description: This is a base strategy class and the BigFish strategy

# author:jiawenze
import backtrader as bt

def StrategyhelloWorld3():
    print("Hello World from helloworld3 in myModeule2.py in package myPackage")

class BLBaseStrategy(bt.Strategy):
    def __init__(self):
        print("BLBaseStrategy.__init__ called")
    def Test(self):
        print("BLBaseStrategy Test")

    fish:list=(3,5,6)




# Create a Stratey
class BLBigFishStrategy(BLBaseStrategy):
    params = (('p1', 10), ('p2', 30),)

    def log(self, txt, dt=None):
        ''' Logging function fot this strategy'''
        dt = dt or self.datas[0].datetime.date(0)
        print('%s, %s' % (dt.isoformat(), txt))

    def __init__(self):
        # Keep a reference to the "close" line in the data[0] dataseries
        self.dataclose = self.datas[0].close

        # To keep track of pending orders and buy price/commission
        self.order = None
        self.buyprice = None
        self.buycomm = None

        # Add a MovingAverageSimple indicator
        
        #self.sma = bt.indicators.SimpleMovingAverage(
        #    self.datas[0], period=self.params.maperiod)
        sma1 = bt.indicators.SMA(period=self.p.p1)
        sma2 = bt.indicators.SMA(period=self.p.p2)
        self.DiffMaSignal = sma1 - sma2
        #buy_sig = bt.And(close_over_sma, close_over_ema, DiffMaSignal > 0)
        self.buy_sig = bt.And(True, self.DiffMaSignal > 0)
        self.sell_sig = bt.And(self.DiffMaSignal < 0,True)

        # Indicators for the plotting show
        #bt.indicators.ExponentialMovingAverage(self.datas[0], period=25)
        #bt.indicators.WeightedMovingAverage(self.datas[0], period=25,
        #                                    subplot=True)
        bt.indicators.StochasticSlow(self.datas[0])
        bt.indicators.MACDHisto(self.datas[0])
        rsi = bt.indicators.RSI(self.datas[0])
        bt.indicators.SmoothedMovingAverage(rsi, period=10)
        bt.indicators.ATR(self.datas[0], plot=False)

    def notify_order(self, order):
        if order.status in [order.Submitted, order.Accepted]:
            # Buy/Sell order submitted/accepted to/by broker - Nothing to do
            return

        # Check if an order has been completed
        # Attention: broker could reject order if not enough cash
        if order.status in [order.Completed]:
            if order.isbuy():
                self.log(
                    'BUY EXECUTED, Price: %.2f, Cost: %.2f, Comm %.2f' %
                    (order.executed.price,
                     order.executed.value,
                     order.executed.comm))

                self.buyprice = order.executed.price
                self.buycomm = order.executed.comm
            else:  # Sell
                self.log('SELL EXECUTED, Price: %.2f, Cost: %.2f, Comm %.2f' %
                         (order.executed.price,
                          order.executed.value,
                          order.executed.comm))

            self.bar_executed = len(self)

        elif order.status in [order.Canceled, order.Margin, order.Rejected]:
            self.log('Order Canceled/Margin/Rejected')

        # Write down: no pending order
        self.order = None

    def notify_trade(self, trade):
        if not trade.isclosed:
            return

        self.log('OPERATION PROFIT, GROSS %.2f, NET %.2f' %
                 (trade.pnl, trade.pnlcomm))

    def next(self):
        # Simply log the closing price of the series from the reference
        #self.log('Close, %.2f' % self.dataclose[0])

        # Check if an order is pending ... if yes, we cannot send a 2nd one
        if self.order:
            return

        # Check if we are in the market
        if not self.position:

            # Not yet ... we MIGHT BUY if ...
            #if self.dataclose[0] > self.sma[0]:
            if self.buy_sig:

                # BUY, BUY, BUY!!! (with all possible default parameters)
                self.log('BUY CREATE, %.2f' % self.dataclose[0])

                # Keep track of the created order to avoid a 2nd order
                self.order = self.buy()

        else:

            #if self.dataclose[0] < self.sma[0]:
            if self.sell_sig:
                # SELL, SELL, SELL!!! (with all possible default parameters)
                self.log('SELL CREATE, %.2f' % self.dataclose[0])

                # Keep track of the created order to avoid a 2nd order
                self.order = self.sell()


from __future__ import (absolute_import, division, print_function,
                        unicode_literals)

import datetime  # For datetime objects
import os.path  # To manage paths
import sys  # To find out the script name (in argv[0])

# Import the backtrader platform
import backtrader as bt

import yfinance as yf

# Create a Stratey
class TestStrategy(bt.Strategy):

    def log(self, txt, dt=None):
        ''' Logging function for this strategy'''
        dt = dt or self.datas[0].datetime.date(0)
        print('%s, %s' % (dt.isoformat(), txt))

    def __init__(self):
        # Keep a reference to the "close" line in the data[0] dataseries
        self.dataclose = self.datas[0].close

    def next(self):
        # Simply log the closing price of the series from the reference
        self.log('Close, %.2f' % self.dataclose[0])


if __name__ == '__main__':
    # Create a cerebro entity
    cerebro = bt.Cerebro()

    # Add a strategy
    cerebro.addstrategy(TestStrategy)

    # Datas are in a subfolder of the samples. Need to find where the script is
    # because it could have been called from anywhere
    modpath = os.path.dirname(os.path.abspath(sys.argv[0]))
    datapath = os.path.join(modpath, '../../datas/orcl-1995-2014.txt')

    # Create a Data Feed
    """ data = bt.feeds.YahooFinanceCSVData(
        dataname=datapath,
        # Do not pass values before this date
        fromdate=datetime.datetime(2000, 1, 1),
        # Do not pass values before this date
        todate=datetime.datetime(2000, 12, 31),
        # Do not pass values after this date
        reverse=False)
    """

    data = bt.feeds.PandasData(dataname=yf.download('SPY', '2015-07-06', '2021-07-01', auto_adjust=True))
    
    # Add the Data Feed to Cerebro
    cerebro.adddata(data)

    # Set our desired cash start
    cerebro.broker.setcash(100000.0)

    # Print out the starting conditions
    print('Starting Portfolio Value: %.2f' % cerebro.broker.getvalue())

    # Run over everything
    cerebro.run()

    # Print out the final result
    print('Final Portfolio Value: %.2f' % cerebro.broker.getvalue())


#!/usr/bin/env python
#  -*- coding: utf-8 -*-
__author__ = 'jiawenze'

if __name__ == "__main__":
    print("Loading BLTrade.BLStrategy as main programme")
else:
    print("Running BLTrade.BLStrategy as a package")


# Python查找算法
# author:jiawenze
# date:2024-7-24

from typing import List,TypeVar,Generic

T = TypeVar('T')

def get_first(items: List[T]) -> T:
        """Return the first item in a list."""

        if items:
                return items[0]

def get_last(items:List[T]) -> T:
        """Return the last item in a list."""

        if items:
                return items[-1]


#test
"""
a=[81,2,3,4,15]
print(get_first([1,2,3,4,5]))
print(get_first(a))
print(get_last([1,2,3,4,5]))
print(get_last(a))
print(get_last([1]))
"""



# BLBackTest framework
# author:jiawenze
# date: 2024/06/27

from __future__ import (absolute_import, division, print_function,
                        unicode_literals)

import datetime  # For datetime objects
import os.path  # To manage paths
import sys  # To find out the script name (in argv[0])


# Import the backtrader platform
import backtrader as bt
import yfinance as yf



class BLBigFishSignal(bt.Indicator):
    lines = ('signal',)
    params = (('p1', 5), ('p2', 30),)

    def __init__(self):
        sma1 = bt.indicators.SMA(period=self.p.p1)
        sma2 = bt.indicators.SMA(period=self.p.p2)
        self.lines.signal = sma1 - sma2
        print(f"sma1={sma1}")
        print(f"sma2={sma2}")
        print(self.lines.signal)


    def next(self):
        #print("lines:处理了%d个数据, 总共有%d个数据" % (len(self.lines),self.lines.buflen()))
        #print("data:已经处理了%d个数据, 总共有%d个数据" % (len(self.data),self.data.buflen()))
        print(self.data.close)
        




if __name__ == '__main__':
    # Create a cerebro entity
    cerebro = bt.Cerebro()

    # Add a strategy
    #cerebro.addstrategy(TestStrategy)

    # Datas are in a subfolder of the samples. Need to find where the script is
    # because it could have been called from anywhere
    modpath = os.path.dirname(os.path.abspath(sys.argv[0]))
    datapath = os.path.join(modpath, '../datas/orcl-1995-2014.txt')

    # Create a Data Feed
    data = bt.feeds.YahooFinanceCSVData(
    dataname=datapath,  
    # Do not pass values before this date
    fromdate=datetime.datetime(2000, 1, 1),
    # Do not pass values before this date
    todate=datetime.datetime(2000, 12, 31),
    # Do not pass values after this date
    reverse=False)
    
    #data = bt.feeds.PandasData(dataname=yf.download('AAPL', '2000-07-06', '2020-07-07', auto_adjust=True))

    #data = bt.feeds.PandasData(dataname=yf.download('AAPL', '2018-07-01', '2021-07-30', auto_adjust=False))
    
    # Add the Data Feed to Cerebro
    cerebro.adddata(data)

    cerebro.add_signal(bt.SIGNAL_LONG,
                           BLBigFishSignal,
                           p1=10,
                           p2=2)

    # Set our desired cash start
    cerebro.broker.setcash(1000.0)

    # Add a FixedSize sizer according to the stake
    cerebro.addsizer(bt.sizers.FixedSize, stake=10)

    # Set the commission
    cerebro.broker.setcommission(commission=0.0)

    # Print out the starting conditions
    print('Starting Portfolio Value: %.2f' % cerebro.broker.getvalue())

    # Run over everything
    cerebro.run()

    # Print out the final result
    print('Final Portfolio Value: %.2f' % cerebro.broker.getvalue())

    # Plot the result
    cerebro.plot()



from __future__ import (absolute_import, division, print_function,
                        unicode_literals)

import datetime  # For datetime objects
import os.path  # To manage paths
import sys  # To find out the script name (in argv[0])

# Import the backtrader platform
import backtrader as bt
import yfinance as yf

import bltrade.blstrategy.BLMainStrategy as bs
import bltrade.blnet.BLMailTip as bm
import asyncio


# 修改买卖点样式
class my_BuySell(bt.observers.BuySell):
    params = (('barplot', True), ('bardist', 0.1)) # bardist 控制买卖点与行情线之间的距离
    plotlines = dict(
    buy=dict(marker=r'$\Uparrow$', markersize=10.0, color='#d62728' ),
    sell=dict(marker=r'$\Downarrow$', markersize=10.0, color='#2ca02c'))

if __name__ == '__main__':
    # Create a cerebro entity
    cerebro = bt.Cerebro()

    # Add a strategy
    cerebro.addstrategy(bs.BLBigFishStrategy)

    # Datas are in a subfolder of the samples. Need to find where the script is
    # because it could have been called from anywhere
    modpath = os.path.dirname(os.path.abspath(sys.argv[0]))
    datapath = os.path.join(modpath, '../datas/orcl-1995-2014.txt')
  

    # Create a Data Feed
    data = bt.feeds.YahooFinanceCSVData(
    dataname=datapath,  
    # Do not pass values before this date
    fromdate=datetime.datetime(2000, 1, 1),
    # Do not pass values before this date
    todate=datetime.datetime(2000, 12, 31),
    # Do not pass values after this date
    reverse=False)
    
    #data = bt.feeds.PandasData(dataname=yf.download('AAPL', '2000-07-06', '2020-07-07', auto_adjust=True))

    #data = bt.feeds.PandasData(dataname=yf.download('AAPL', '2018-07-01', '2021-07-30', auto_adjust=False))
    
    # Add the Data Feed to Cerebro
    cerebro.adddata(data)

    # Set our desired cash start
    cerebro.broker.setcash(1000.0)

    # Add a FixedSize sizer according to the stake
    cerebro.addsizer(bt.sizers.FixedSize, stake=10)

    # Set the commission
    cerebro.broker.setcommission(commission=0.0)

    # Print out the starting conditions
    print('Starting Portfolio Value: %.2f' % cerebro.broker.getvalue())

    asyncio.run(bm.SendMail('Starting Portfolio Value: %.2f' % cerebro.broker.getvalue()))

    #cerebro.addobserver(my_BuySell) 
    bt.observers.BuySell = my_BuySell



    # Run over everything
    cerebro.run()

    # Print out the final result
    print('Final Portfolio Value: %.2f' % cerebro.broker.getvalue())

    # Plot the result
    #cerebro.plot()
    cerebro.plot(
        iplot=True, 
        numfigs=1,
        width=16,
        height=9,
        style='candel',
        #style='line', 
        plotdist=0.1, # 设置图形之间的间距
        barup = '#ff9896', bardown='#98df8a', 
        volup='#ff9896', voldown='#98df8a', 
        
        bartrans=0.2
    )


# BLTrade Version
import subprocess
import configparser



# Git版本提交次数
def GetGitPushCount():
    
    gitpushcount=subprocess.getoutput('git rev-list --count HEAD')
    return gitpushcount

# 获取版本号
def GetDevVersion():
    try:
        BLTradeVersion=GetGitPushCount()
        #BLTradeVersion=subprocess.getoutput('gitx')
        #return f"BLTrade Engine Version: {int(BLTradeVersion)/1000}"
        # 始终保留三位子版本号
        # eg: 1.025
        return f"{format(float(BLTradeVersion)/1000, '.3f')}"
    except ValueError:
        print("Excepted: git命令执行失败!!!")
        BLTradeVersion=287
        #return f"BLTrade Engine Version: {int(BLTradeVersion)/1000}"
        return f"{int(BLTradeVersion)/1000}"
    
def GetVersion():
        
        file = "bltrade/config/version.ini"

        # 创建配置文件对象
        conf=configparser.ConfigParser()

        # 读取文件
        conf.read(file, encoding='utf-8')

        # 获取所有section
        #sections = conf.sections()
        # ['url', 'email']


        # 获取特定section
        #items = con.items('url') 	# 返回结果为元组
        # [('baidu','http://www.baidu.com'),('port', '80')] 	# 数字也默认读取为字符串

        # 可以通过dict方法转换为字典
        #items = dict(items)

        # 获取特定section
        #items = conf.items('version') 	# 返回结果为元组
        #print(items)

        version=conf.get('version','bltradeversion')
        print(version)

        BLTradeVersion=version
        #return f"BLTrade Engine Version: {int(BLTradeVersion)/1000}"
        #return f"{int(BLTradeVersion)/1000}"
        return BLTradeVersion


        
    

#print(GetVersion())


from __future__ import (absolute_import, division, print_function,
                        unicode_literals)
import backtrader as bt
import yfinance as yf



 
if __name__ == '__main__':
    cerebro = bt.Cerebro()
    print('Starting Portfolio Value: %.2f' % cerebro.broker.getvalue())
    cerebro.run()
    print('Final Portfolio Value: %.2f' % cerebro.broker.getvalue())

    data = yf.download("AAPL", period="max")  # download all
    print(data)




# 一键平仓
# 以超价一键平仓
def blEmpty(api:any):
    position = api.get_position()
    #print("----------------position---------------")
    #print(position)

    print("----------------1 检测当前仓位信息------------------------------------------------------")
    for n,p in position.items():
        #print("name=",n,"p=",p)
        print("品种:",n,"浮盈：",p.float_profit_long + p.float_profit_short,"   多仓:",p.pos_long,"空仓:",p.pos_short)
        quote = api.get_quote(n)
        #print(quote)
        print("合约代码：",quote.instrument_id,"卖1:",quote.ask_price1,"买1:",quote.bid_price1)
        
        print("开始平仓：",quote.instrument_id,"------------------------------------------------")

        if p.pos_long>0:
            print("需要平仓多仓",p.pos_long,"手")
            order = api.insert_order(symbol=quote.instrument_id, direction="SELL", offset="CLOSETODAY", limit_price=quote.bid_price1-2*quote.price_tick,
                volume=p.pos_long)

            while order.status != "FINISHED":
                api.wait_update()
                print("合约代码：",quote.instrument_id,"已平仓")


        if p.pos_short>0:
            print("需要平仓空仓",p.pos_short,"手")
            order = api.insert_order(symbol=quote.instrument_id, direction="BUY", offset="CLOSETODAY", limit_price=quote.ask_price1+2*quote.price_tick,
                volume=p.pos_short)

            while order.status != "FINISHED":
                api.wait_update()
                print("合约代码：",quote.instrument_id,"已平仓")

# 一键撤销
# 撤销所有status为"ALIVE"的单
def blQuash(api:any):
    orders=api.get_order()
    #print(orders)
    for i,o in orders.items():
        #print("i=",i,"o=",o)
        if o['status']=="ALIVE":
            api.cancel_order(o)



# 异步调用支持
import asyncio
# 网络延迟测试
import ping3
# gmail
import smtplib
from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText
from email.utils import formataddr
from email.mime.base import MIMEBase
from email import encoders


# 发件人和收件人信息
sender_email = "774190438@qq.com"
receiver_email = "774190438@qq.com"
password = "jocbkltbzmysbfgf"
smtp_server = "smtp.qq.com"  # QQ邮箱的SMTP服务器地址
smtp_port = 587  # QQ邮箱的SMTP服务器端口（通常为587）


async def SendMail(self,*text: any)->None:
    try:
        """发送提醒消息"""
        # 登录QQ邮箱
        server = smtplib.SMTP(smtp_server, smtp_port)
        server.starttls()  # 启用TLS加密
        server.login(sender_email, password)


        # 发送邮件

        #subject = "策略提醒 ag2408 %d" % price
        subject = str(text)
        contents = str(text)
        #subject = "策略提醒"
        #contents = "策略提醒"

        msg = MIMEText(contents, 'plain', 'utf-8')  # 填写邮件内容
        msg['From'] = formataddr(["BLEngine量化管家", sender_email])  # 括号里的对应发件人邮箱昵称、发件人邮箱账号
        msg['To'] = formataddr(["二寸丹心", receiver_email])  # 括号里的对应收件人邮箱昵称、收件人邮箱账号
        msg['Subject'] = subject  # 邮件的主题，也可以说是标题
        # yag.send(receiver_email, subject, contents)
        server.sendmail(sender_email, receiver_email, msg.as_string())  # 括号中对应的是发件人邮箱账号、收件人邮箱账号、发送邮件
        
        server.quit()  # 关闭连接
        #self.output("邮件已发送成功！")
        print("邮件已发送成功！")


    except smtplib.SMTPServerDisconnected:
        #self.output("SMTP服务器连接中断")
        print("SMTP服务器连接中断")
        #server.quit()  # 关闭连接
        # 登录QQ邮箱
        #server = smtplib.SMTP(smtp_server, smtp_port)
        #server.starttls()  # 启用TLS加密
        #server.login(sender_email, password)
        #self.output("邮箱已登录")
    #except smtplib.SMTPAuthenticationError:
        #self.output("登录认证失败")
        
    #except Exception as e:
        #self.output(f"发送邮件时发生错误: {e}")


def NetDelay(self)->int:
    delay=ping3.ping("www.baidu.com")
    if delay is not None:
        ret=delay
    else:
        ret=999
    return ret


from setuptools import setup, find_packages
import bltrade.bltrade.BLTradeVersion as bv
from os import path
this_directory = path.abspath(path.dirname(__file__))
#long_description = "BLTrade"
long_description = f"bltrade version:{bv.GetVersion()}，是可以嵌入任何交易软件的Trade工具库。"
print(long_description)
#with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
#    long_description = f.read()
 
setup(name='BLTrade', # 包名称
        #packages=find_packages(include=['bltrade', 'bltrade.blback']),
        packages=find_packages().append(["test","datas","doc","config"]),
        #include_package_data=True, # 需要处理的包目录
        
        #version='0.26', # 版本
        version=bv.GetVersion(),
        classifiers=[
            'Development Status :: 3 - Alpha',
            'License :: OSI Approved :: MIT License',
            'Programming Language :: Python', 'Intended Audience :: Developers',
            'Operating System :: OS Independent',
            'Programming Language :: Python :: 3.8',
            'Programming Language :: Python :: 3.9',
            'Programming Language :: Python :: 3.12',
        ],
        install_requires=['backtrader'],
        #entry_points={'console_scripts': ['pmm=pimm.pimm_module:main']},
        package_data={'': ['*.txt','*.csv','*.docx','*.ini']},
        author='Jiawenze', # 作者
        author_email='s.gua@163.com', # 作者邮箱
        description='BLTrade', # 介绍
        long_description=long_description, # 长介绍，在pypi项目页显示
        long_description_content_type='text/markdown', # 长介绍使用的类型，我使用的是md
        url='', # 包主页，一般是github项目主页
        license='MIT', # 协议
        keywords='BLTrade',
        #packages=["BLTrade","BLStrategy","test","BLBack","BLNetwork","datas"],
      ) # 关键字 搜索用


#!/usr/bin/env python
#  -*- coding: utf-8 -*-
__author__ = 'chengzhi'

from datetime import date
from tqsdk import TqApi, TqAuth, TqBacktest, TargetPosTask,TqSim,BacktestFinished
acc = TqSim()
'''
回测从 2018-05-01 到 2018-10-01
'''
# 在创建 api 实例时传入 TqBacktest 就会进入回测模式
api = TqApi(acc,backtest=TqBacktest(start_dt=date(2018, 5, 1), end_dt=date(2018, 10, 1)), auth=TqAuth("billin", "dnadna"))
# get m1901 5m KLine
klines = api.get_kline_serial("DCE.m1901", 5 * 60, data_length=15)
# 创建 m1901 的目标持仓 task，该 task 负责调整 m1901 的仓位到指定的目标仓位
target_pos = TargetPosTask(api, "DCE.m1901")


print(acc.tqsdk_stat)  # 回测时间内账户交易信息统计结果，其中包含以下字段
# 由于需要在浏览器中查看绘图结果，因此程序不能退出
while True:
    api.wait_update()
    if api.is_changing(klines):
        ma = sum(klines.close.iloc[-15:]) / 15
        print("Latest Price", klines.close.iloc[-1], "MA", ma)
        if klines.close.iloc[-1] > ma:
            print("Latest>MA: buy 5")
            # buy
            target_pos.set_target_volume(5)
        elif klines.close.iloc[-1] < ma:
            print("Latest<MA: balance")
            # balance
            target_pos.set_target_volume(0)
